==> ffmpeg-4.3.1-1.5.4-sources.jar: org/bytedeco/ffmpeg/presets/swresample.java <==
/*
 * Copyright (C) 2013-2018 Samuel Audet
 *
 * Licensed either under the Apache License, Version 2.0, or (at your option)
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation (subject to the "Classpath" exception),
 * either version 2, or any later version (collectively, the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     http://www.gnu.org/licenses/
 *     http://www.gnu.org/software/classpath/license.html
 *
 * or as provided in the LICENSE.txt file that accompanied this code.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bytedeco.ffmpeg.presets;

import org.bytedeco.javacpp.annotation.Platform;
import org.bytedeco.javacpp.annotation.Properties;
import org.bytedeco.javacpp.tools.InfoMap;
import org.bytedeco.javacpp.tools.InfoMapper;

/**
 *
 * @author Samuel Audet
 */
@Properties(
    inherit = avutil.class,
    target = "org.bytedeco.ffmpeg.swresample",
    global = "org.bytedeco.ffmpeg.global.swresample",
    value = {
        @Platform(cinclude = "<libswresample/swresample.h>", link = "swresample@.3"),
        @Platform(value = "windows", preload = "swresample-3")
    }
)
public class swresample implements InfoMapper {
    public void map(InfoMap infoMap) {
    }
}

==> ffmpeg-5.0-1.5.7-sources.jar: org/bytedeco/ffmpeg/presets/swresample.java <==
/*
 * Copyright (C) 2013-2022 Samuel Audet
 *
 * Licensed either under the Apache License, Version 2.0, or (at your option)
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation (subject to the "Classpath" exception),
 * either version 2, or any later version (collectively, the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     http://www.gnu.org/licenses/
 *     http://www.gnu.org/software/classpath/license.html
 *
 * or as provided in the LICENSE.txt file that accompanied this code.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bytedeco.ffmpeg.presets;

import org.bytedeco.javacpp.annotation.Platform;
import org.bytedeco.javacpp.annotation.Properties;
import org.bytedeco.javacpp.tools.Info;
import org.bytedeco.javacpp.tools.InfoMap;
import org.bytedeco.javacpp.tools.InfoMapper;

/**
 *
 * @author Samuel Audet
 */
@Properties(
    inherit = avutil.class,
    target = "org.bytedeco.ffmpeg.swresample",
    global = "org.bytedeco.ffmpeg.global.swresample",
    value = {
        @Platform(cinclude = {"<libswresample/swresample.h>", "<libswresample/version.h>"}, link = "swresample@.4"),
        @Platform(value = "windows", preload = "swresample-4")
    }
)
public class swresample implements InfoMapper {
    public void map(InfoMap infoMap) {
        infoMap.put(new Info("LIBSWRESAMPLE_VERSION").cppTypes())
               .put(new Info("LIBSWRESAMPLE_VERSION_INT", "LIBSWRESAMPLE_IDENT").translate(false));
    }
}
